==> ja-WiKicker-0.23.tbz: lib/perl5/site_perl/5.8.5/WiKicker/WRI/Image.pm <==
#
# WiKicker
#
#  Image.pm
#
#
# Copyright (C) 2003 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: Image.pm,v 1.5 2004/04/02 12:20:24 naney Exp $
#
#

package WiKicker::WRI::Image;

use strict;
use Carp;
use WiKicker::WRI::RWRN;

use vars qw(@ISA);
@ISA = qw(WiKicker::WRI::RWRN);

sub get_link_url {
  my ($self, $env) = @_;

  #my $rest_wri = WiKicker::WRI::Factory::create($self->rest);
  croak "no env" unless defined $env;
  croak ref($self) . ": get_link_url(): no env/wri_factory"
    unless defined $env->wri_factory;
  my $rest_wri = $env->wri_factory->create_wri($self->rest);
  return $rest_wri->get_link_url($env);
}

sub get_image_url {
  my ($self, $env) = @_;

  my $rest = $self->rest;
  if ($rest =~ /^(ASIN|asin):(.*)$/) {
    return $env->resolver->get_asin_image_url($2);
  }
  if ($rest =~ /^(ISBN|isbn):(.*)$/) {
    my $isbn = $2;
    $isbn =~ s/-//g;
    return $env->resolver->get_isbn_image_url($isbn);
  }
  else {
    return $rest;
  }
}

sub _make_image_link_html {
  my ($self, $content, $image_url, $env) = @_;
  my $href = $self->get_link_url($env);
  my $alt_string = WiKicker::HTML::escape($content || $self->to_string);

  my $align = '';
  my $scheme = $self->scheme;
  if ($scheme eq 'limage') {
    $align = qq( class="left");
  }
  elsif ($scheme eq 'rimage') {
    $align = qq( class="right");
  }

  if ($href) {
    return qq(<a href="$href"><img src="$image_url" alt="$alt_string"$align></a>);
  }
  else {
    return qq(<img src="$image_url" alt="$alt_string"$align>);
  }
}

sub to_subject_string {
  my ($self, $env) = @_;

  return '';
}

1;

==> ja-WiKicker-0.26.tbz: lib/perl5/site_perl/5.8.9/WiKicker/WRI/Image.pm <==
#
# WiKicker
#
#  Image.pm
#
#
# Copyright (C) 2003,2004,2005 WATANABE Yoshimasa <naney@naney.org>
#
# This file is part of the WiKicker.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the Free
# Software Foundation; either version 2 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc., 59
# Temple Place, Suite 330, Boston, MA 02111-1307 USA
#
#
# $Id: Image.pm,v 1.8 2005/03/20 10:44:26 naney Exp $
#
#

package WiKicker::WRI::Image;

use strict;
use Carp;
use WiKicker::WRI::RWRN;

use vars qw(@ISA);
@ISA = qw(WiKicker::WRI::RWRN);

sub get_link_url {
  my ($self, $env) = @_;

  #my $rest_wri = WiKicker::WRI::Factory::create($self->rest);
  croak 'no env' unless defined $env;
  croak ref($self) . ": get_link_url(): no env/wri_factory"
    unless defined $env->wri_factory;
  my $rest_wri = $env->wri_factory->create_wri($self->rest);
  return $rest_wri->get_link_url($env);
}

sub get_image_url {
  my ($self, $env) = @_;

  my $rest = $self->rest;
  if ($rest =~ /^(ASIN|asin):(.*)$/) {
    return $env->resolver->get_asin_image_url($2);
  }
  if ($rest =~ /^(ISBN|isbn):(.*)$/) {
    my $isbn = $2;
    $isbn =~ s/-//g;
    return $env->resolver->get_isbn_image_url($isbn);
  }
  else {
    return $rest;
  }
}

sub _make_image_link_html {
  my ($self, $content, $image_url, $env) = @_;

  my $img_src = WiKicker::HTML::escape_attribute($image_url);
  my $href    = WiKicker::HTML::escape_attribute($self->get_link_url($env));
  my $alt     = WiKicker::HTML::escape_attribute($content || $self->to_string);

  my $align = '';
  my $scheme = $self->scheme;
  if ($scheme eq 'limage') {
    $align = qq( class="left");
  }
  elsif ($scheme eq 'rimage') {
    $align = qq( class="right");
  }

  if ($href && ($href ne $img_src)) {
    return qq(<a href="$href"><img src="$img_src" alt="$alt"$align></a>);
  }
  else {
    return qq(<img src="$img_src" alt="$alt"$align>);
  }
}

sub to_subject_string {
  my ($self, $env) = @_;

  return '';
}

1;
